send_result

Function send_result 

pub fn send_result(sid: u64, status: NrStatus, data: NrVec<u8>) -> NrStatus
Sends a response or stream frame for sid through the host’s send_result. Borrowed payloads (owned = 0) are copied by the host before this returns. Reports Invalid when the plugin has not been initialized.