pub struct NrAny { /* private fields */ }Expand description
A type-erased value that can hold any data type.
This struct is #[repr(C)] and ABI-stable.
Implementations
Sourceimpl NrAny
impl NrAny
Sourcepub fn new<T: Clone + Send + Sync + 'static>(value: T, type_tag: u32) -> Self
pub fn new<T: Clone + Send + Sync + 'static>(value: T, type_tag: u32) -> Self
Stores a clonable, thread-safe Rust value behind the ABI container.
Sourcepub fn from_bytes(bytes: &[u8], type_tag: u32) -> Self
pub fn from_bytes(bytes: &[u8], type_tag: u32) -> Self
Stores an owned copy of a byte slice as a Vec<u8>.
Sourcepub fn as_ptr<T>(&self) -> Result<*const T, NrStatus>
pub fn as_ptr<T>(&self) -> Result<*const T, NrStatus>
Returns a typed raw pointer after checking the stored byte size.
The user-defined type tag is not a Rust type identifier. The caller
must verify NrAny::type_tag before dereferencing the returned pointer.
pub fn as_mut_ptr<T>(&mut self) -> Result<*mut T, NrStatus>
pub fn is_null(&self) -> bool
pub fn type_tag(&self) -> u32
pub fn size(&self) -> u64